pub struct ReadBranchLinkV0 {
pub repo: PubKey,
pub branch: PubKey,
pub topic: PubKey,
pub heads: Vec<BlockRef>,
pub read_cap: BlockRef,
pub overlay: OverlayLink,
pub peers: Vec<PeerAdvert>,
}Expand description
Read access to a branch of a Public, Protected or Group store.
The overlay to join can be the outer or the inner, depending on what was offered in the link. The difference between the two is that in the outer overlay, only one broker is contacted. In the inner overlay, all the publisher’s brokers are contacted, so subscription to the pub/sub is more reliable, less prone to outage. This is not a durable link. If the topic has been refreshed, the pubsub won’t be able to be subscribed to, but TopicSyncReq will still work (answering the commits up until the moment the topic was refreshed) and the optional heads will always be retrievable
Fields
repo: PubKeyRepository ID
branch: PubKeytopic: PubKeyheads: Vec<BlockRef>an optional list of heads that can be fetched in this branch useful if a specific head is to be shared
read_cap: BlockRefread capability for the branch current (at the time of sharing the link) branch definition commit
overlay: OverlayLinkCurrent overlay link, used to join the overlay, most of the time, an outerOverlay is preferred
peers: Vec<PeerAdvert>Peer brokers to connect to