pub struct SubMarkerV0 {
pub publisher: PubKey,
pub topic: PubKey,
pub subscriber: PubKey,
pub known_heads: Vec<Digest>,
}Expand description
Topic subscription marker sent by all publishers, back to subscriber
Forwarded to all subscribers.
Fields
publisher: PubKeyThe publisher broker that marks its starting cut TODO: that could be omitted, because we can retrieve it with the SessionId
topic: PubKeyThe subscribed topic
subscriber: PubKeyThe subscriber
known_heads: Vec<Digest>Current heads at the broker when receiving the SubReq. Can be used to safely do a CoreTopicSyncReq