Wallet

Enum Wallet 

pub enum Wallet {
    V0(WalletV0),
    TemporarilyEmpty,
}
Wallet info

Variants



V0(WalletV0)



TemporarilyEmpty

Implementations

Source

impl Wallet

pub fn id(&self) -> PubKey

pub fn content_as_bytes(&self) -> Vec<u8>

pub fn sig(&self) -> Sig

pub fn pazzle_length(&self) -> u8

pub fn name(&self) -> String

pub fn encrypt( &self, wallet_log: &WalletLog, master_key: &[u8; 32], peer_id: PubKey, nonce: u64, wallet_privkey: PrivKey, ) -> Result<Wallet, NgWalletError>

nonce : The current nonce used for encrypting this wallet by the user on this device. It should be incremented BEFORE encrypting the wallet again when some new operations have been added to the log of the Wallet. The nonce is by PeerId. It is saved together with the PeerId in the SessionPeerStorage. If the session is not saved (in-memory) it is lost, but it is fine, as the PeerId is also lost, and a new one will be generated for the next session.