CreateWalletV0

Struct CreateWalletV0 

pub struct CreateWalletV0 {
Show 13 fields pub security_img: Vec<u8>, pub security_txt: String, pub pin: [u8; 4], pub pazzle_length: u8, pub send_bootstrap: bool, pub send_wallet: bool, pub result_with_wallet_file: bool, pub local_save: bool, pub core_bootstrap: BootstrapContentV0, pub core_registration: Option<[u8; 32]>, pub additional_bootstrap: Option<BootstrapContentV0>, pub pdf: bool, pub device_name: String,
}
Create Wallet Version 0, used by the API create_wallet_v0 as a list of arguments

Fields

security_img: Vec<u8>

a vector containing the binary content of an image file that will be used at every login, displayed (on devices that can) to the user so they can check the wallet is theirs and that entering their pazzle and PIN is safe and there is no phishing attack. an attacker would redirect the user to a clone of the wallet opener app, and would try to steal what the user enters but this attacker would not possess the security_img of the user as it is only present locally in the wallet file. the image should be bigger than 150x150px. There is no need to provide more than 400x400px as it will be scaled down anyway. We accept several formats like JPEG, PNG, GIF, WEBP and more. The image should be unique to the user. But it should not be too personal neither. Do not upload face picture, this is not a profile pic. The best would be any picture that the user recognizes as unique. Please be aware that other users who are sharing the same device, will be able to see this image.

security_txt: String

A string of characters of minimum length 10. This phrase will be presented to the user every time they are about to enter their pazzle and PIN in order to unlock their wallet. It should be something the user will remember, but not something too personal. Do not enter full name, nor address, nor phone number. Instead, the user can enter a quote, a small phrase that they like, or something meaningless to others, but unique to them. Please be aware that other users who are sharing the same device, will be able to see this phrase.

pin: [u8; 4]

chose a PIN code. We recommend the user to choose a PIN code they already know very well (unlock phone, credit card). The PIN and the rest of the Wallet will never be sent to NextGraph or any other third party (check the source code if you don’t believe us). It cannot be a series like 1234 or 8765. The same digit cannot repeat more than once. By example 4484 is invalid. Try to avoid birth date, last digits of phone number, or zip code for privacy concern

pazzle_length: u8

For now, only 9 is supported. 12 and 15 are planned. A value of 0 will deactivate the pazzle mechanism on this Wallet, and only the mnemonic could be used to open it.

send_bootstrap: bool

Not implemented yet. Will send the bootstrap to our cloud servers, if needed

send_wallet: bool

Not implemented yet. Will send an encrypted Wallet file to our cloud servers, if needed. (and no, it does not contain the user’s pazzle nor PIN)

result_with_wallet_file: bool

Do you want a binary file containing the whole Wallet ?

local_save: bool

Should the wallet be saved locally on disk, by the LocalBroker. It will not work on a in-memory LocalBroker, obviously.

core_bootstrap: BootstrapContentV0

What Broker Server to contact when there is internet and we want to sync.

core_registration: Option<[u8; 32]>

What is the registration code at that Broker Server. Only useful the first time you connect to the Server. Can be None the rest of the time, or if your server does not need an Invitation.

additional_bootstrap: Option<BootstrapContentV0>

Bootstrap of another server that you might use in order to connect to NextGraph network. It can be another interface on the same core server.

pdf: bool

Should generate a recovery PDF containing all the information of the wallet in plain text.

device_name: String

short name of the device

Implementations

Source

impl CreateWalletV0

pub fn new( security_img: Vec<u8>, security_txt: String, pin: [u8; 4], pazzle_length: u8, send_bootstrap: bool, send_wallet: bool, core_bootstrap: BootstrapContentV0, core_registration: Option<[u8; 32]>, additional_bootstrap: Option<BootstrapContentV0>, pdf: bool, device_name: String, ) -> CreateWalletV0